@@ -3,6 +3,7 @@ import copy
 import logging
 from pathlib import Path
 from textwrap import dedent
+from datetime import datetime
 from dataclasses import dataclass, field
 from typing import List, Self, Dict, Any, Optional, Sequence, get_args
 
@@ -175,7 +176,8 @@ class CodeActAgent:
                 run_id=run_id,
                 session_id=session_id,
             )
-            system_prompt = self.prompts.system.render(tools=tools)
+            current_date = datetime.now().strftime("%Y-%m-%d")
+            system_prompt = self.prompts.system.render(tools=tools, current_date=current_date)
 
             # Form input messages
             messages = convert_code_to_content(
@@ -324,7 +326,7 @@ class CodeActAgent:
 
         # Execute code
         try:
-            code_result = await python_executor.invoke(code_action)
+            code_result = await python_executor.ainvoke(code_action)
             self._log(
                 f"Code result: {code_result}",
                 run_id=run_id,
@@ -402,7 +404,10 @@ class CodeActAgent:
         ), "Plan suffix is not set, but planning is enabled"
 
         conversation = "\n\n".join([f"{m.role}: {m.content}" for m in messages[1:]])
-        planning_prompt = self.prompts.plan.render(conversation=conversation, tools=tools)
+        current_date = datetime.now().strftime("%Y-%m-%d")
+        planning_prompt = self.prompts.plan.render(
+            conversation=conversation, tools=tools, current_date=current_date
+        )
         input_messages = [ChatMessage(role="user", content=planning_prompt)]
 
         output_stream = self.llm.astream(input_messages, stop=[self.prompts.end_plan_sequence])
