@@ -1,7 +1,10 @@
 import httpx
+import tempfile
+import os
 from typing import Iterator, List, Dict, Any
 
 import gradio as gr
+import fire  # type: ignore
 
 from codearkt.event_bus import AgentEvent, EventType
 from codearkt.llm import ChatMessage
@@ -117,6 +120,25 @@ class GradioUI:
                 save_history=True,
             )
 
+            download_button = gr.DownloadButton(
+                label="💾 Download conversation",
+                variant="secondary",
+            )
+
+            def _download_conversation(real_messages: List[ChatMessage]) -> str:
+                lines = [f"{msg.role}: {msg.content}" for msg in real_messages]
+                text = "\n\n".join(lines)
+
+                fd, path = tempfile.mkstemp(prefix="conversation_", suffix=".txt")
+                with os.fdopen(fd, "w", encoding="utf-8") as f:
+                    f.write(text)
+
+                return path
+
+            download_button.click(
+                _download_conversation, inputs=[real_messages_state], outputs=download_button
+            )
+
             def _on_stop(session_id: str | None) -> str | None:
                 if session_id:
                     stop_agent(session_id)
@@ -125,9 +147,15 @@ class GradioUI:
             chat_iface.textbox.stop(_on_stop, inputs=[session_id_state], outputs=[session_id_state])
         return demo
 
-    def run(self) -> None:
-        self.create_app().launch(show_error=True)
+    def run(self, share: bool = False) -> None:
+        app = self.create_app()
+        app.queue()
+        app.launch(show_error=True, share=share)
+
+
+def main(share: bool = False) -> None:
+    GradioUI().run(share=share)
 
 
 if __name__ == "__main__":
-    GradioUI().run()
+    fire.Fire(main)
