@@ -1,5 +1,6 @@
 import asyncio
 from textwrap import dedent
+from datetime import datetime
 
 from academia_mcp.tools import arxiv_search
 
@@ -74,6 +75,20 @@ class TestCodeActAgent:
         str_result = str(result).replace(",", "").replace(".", "").replace(" ", "")
         assert "1873272970937648109531" in str_result, result
 
+    async def test_codeact_gpt_5_mini(self, gpt_5_mini: LLM) -> None:
+        agent = CodeActAgent(
+            name="agent",
+            description="Just agent",
+            llm=gpt_5_mini,
+            tool_names=[],
+        )
+        result = await agent.ainvoke(
+            [ChatMessage(role="user", content="What is 432412421249 * 4332144219?")],
+            session_id=get_unique_id(),
+        )
+        str_result = str(result).replace(",", "").replace(".", "").replace(" ", "")
+        assert "1873272970937648109531" in str_result, result
+
     async def test_codeact_max_iterations(
         self, deepseek: LLM, mcp_server_test: MCPServerTest
     ) -> None:
@@ -294,3 +309,16 @@ class TestCodeActAgent:
         )
         assert tools[0].description is not None, tools[0].description
         assert tools[0].description.strip() == tools[0].description
+
+    async def test_codeact_current_date(self, deepseek: LLM) -> None:
+        agent = CodeActAgent(
+            name="agent",
+            description="Just agent",
+            llm=deepseek,
+        )
+        result = await agent.ainvoke(
+            [ChatMessage(role="user", content="What is the current date? Use %Y-%m-%d format")],
+            session_id=get_unique_id(),
+        )
+        current_date = datetime.now().strftime("%Y-%m-%d")
+        assert current_date in str(result), result
